==> haskell-bower-json-1.0.0.1-330-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bower-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bower-json
version:              1.0.0.1
visibility:           public
id:                   bower-json-1.0.0.1-ImXAySviZpELdQIFWg3OPl
key:                  bower-json-1.0.0.1-ImXAySviZpELdQIFWg3OPl
license:              MIT
maintainer:           harry@garrood.me
author:               Harry Garrood
homepage:             https://github.com/hdgarrood/bower-json
synopsis:             Read bower.json from Haskell
description:
    Bower is a package manager for the web (see <http://bower.io>).
    This package provides a data type and ToJSON/FromJSON instances for Bower'\''s
    package manifest file, bower.json.

category:             Web
abi:                  0621e699a634ba186acb018ab292847e
exposed:              True
exposed-modules:      Web.Bower.PackageMeta
hidden-modules:       Web.Bower.PackageMeta.Internal
import-dirs:          /usr/lib/ghc-9.0.1/site-local/bower-json-1.0.0.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/bower-json-1.0.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/bower-json-1.0.0.1
hs-libraries:         HSbower-json-1.0.0.1-ImXAySviZpELdQIFWg3OPl
depends:
    aeson-1.5.6.0-5GxEynAdVr82B7C7yhxG6H
    aeson-better-errors-0.9.1.0-C4lWzPtkAmhCRpZKMtUOCe base-4.15.0.0
    bytestring-0.10.12.1 deepseq-1.4.5.0 ghc-prim-0.7.0 mtl-2.2.2
    scientific-0.3.7.0-6YcEb7tz99ZGgIPqqFBkeZ text-1.2.4.1
    transformers-0.5.6.2
    unordered-containers-0.2.14.0-EvtGmSgibELG8puyj0bZfl
    vector-0.12.3.1-BYdg1PRFj4WB38iHU29MVy

haddock-interfaces:   /usr/share/doc/haskell-bower-json/html/bower-json.haddock
haddock-html:         /usr/share/doc/haskell-bower-json/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bower-json-1.0.0.1-332-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bower-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bower-json
version:              1.0.0.1
visibility:           public
id:                   bower-json-1.0.0.1-LlihayjqHE3FExInTUSCtI
key:                  bower-json-1.0.0.1-LlihayjqHE3FExInTUSCtI
license:              MIT
maintainer:           harry@garrood.me
author:               Harry Garrood
homepage:             https://github.com/hdgarrood/bower-json
synopsis:             Read bower.json from Haskell
description:
    Bower is a package manager for the web (see <http://bower.io>).
    This package provides a data type and ToJSON/FromJSON instances for Bower'\''s
    package manifest file, bower.json.

category:             Web
abi:                  1e52e9b8226d1d6ba9f1c806bc70c549
exposed:              True
exposed-modules:      Web.Bower.PackageMeta
hidden-modules:       Web.Bower.PackageMeta.Internal
import-dirs:          /usr/lib/ghc-9.0.1/site-local/bower-json-1.0.0.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/bower-json-1.0.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/bower-json-1.0.0.1
hs-libraries:         HSbower-json-1.0.0.1-LlihayjqHE3FExInTUSCtI
depends:
    aeson-1.5.6.0-FCXpoR7la5e15i9FMLdjlO
    aeson-better-errors-0.9.1.0-xL8QPO8ZloClo67GTEgW6 base-4.15.0.0
    bytestring-0.10.12.1 deepseq-1.4.5.0 ghc-prim-0.7.0 mtl-2.2.2
    scientific-0.3.7.0-CP2rRIG39lTCDzlWk45agq text-1.2.4.1
    transformers-0.5.6.2
    unordered-containers-0.2.14.0-4INWEfzekoJLPsSfbAftPl
    vector-0.12.3.1-EtdN61cdG6Y4MwC0gVwGz6

haddock-interfaces:   /usr/share/doc/haskell-bower-json/html/bower-json.haddock
haddock-html:         /usr/share/doc/haskell-bower-json/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
